
* This syntax produces output required for Figure NU.3: Infant feeding patterns by age, Survey name, Year.


* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file = 'ch.sav'.

weight by chweight.

select if (UF9 = 1 and cage < 24).

* MICS5.
compute bf = 0.
*Exclusively breastfed.
* Only breastfeeding and no other liquid or food (not taking into account medicine or ORS).
if (BD3 = 1 & 
    not any(1, BD7A, BD7B, BD7C, BD7D, BD7E, BD7F,
               BD8A, BD8B, BD8C, BD8D, BD8E, BD8F, BD8G, BD8H, BD8I, BD8J, BD8K, BD8L, BD8M, BD8N, BD8O)) bf = 1.

* Breastfed and plain water only.
if (BD3 = 1 & BD7A = 1 & 
    not any(1, BD7B, BD7C, BD7D, BD7E, BD7F, 
               BD8A, BD8B, BD8C, BD8D, BD8E, BD8F, BD8G, BD8H, BD8I, BD8J, BD8K, BD8L, BD8M, BD8N, BD8O)) bf = 2.

*Breastfed and non-milk liquids.
if (BD3 = 1 & any(1, BD7B, BD7C, BD7F) &
    not any(1, BD7D, BD7E, 
               BD8A, BD8B, BD8C, BD8D, BD8E, BD8F, BD8G, BD8H, BD8I, BD8J, BD8K, BD8L, BD8M, BD8N, BD8O)) bf = 3.

* Breastfed and other milk / formula (milk, formula and yogurt).
if (BD3 = 1 & any(1, BD7D, BD7E, BD8A) & 
    not any(1, BD8B, BD8C, BD8D, BD8E, BD8F, BD8G, BD8H, BD8I, BD8J, BD8K, BD8L, BD8M, BD8N, BD8O)) bf = 4.

* Breastfed and complementary foods.
if (BD3 = 1 & 
        any(1, BD8B, BD8C, BD8D, BD8E, BD8F, BD8G, BD8H, BD8I, BD8J, BD8K, BD8L, BD8M, BD8N, BD8O)) bf = 5.

* Weaned (not breastfed).
if (BD2 <> 1 or BD3 <> 1) bf = 6.

variable labels bf "Infant feeding pattern".
value labels bf 
  1 "Exclusively breastfed"
  2 "Breastfed and plain water only"
  3 "Breastfed and non-milk liquids"
  4 "Breastfed and other milk / formula"
  5 "Breastfed and complementary foods"
  6 "Weaned (not breastfed)" .

compute cage2 = trunc(cage/2).
variable labels cage2 "Age".
value labels cage2 
  0 "0-1"
  1 "2-3"
  2 "4-5"
  3 "6-7"
  4 "8-9"
  5 "10-11"
  6 "12-13"
  7 "14-15"
  8 "16-17"
  9 "18-19"
  10 "20-21"
  11 "22-23" .

compute numChildren = 1.
value labels numChildren 1 "Number of children".

compute total100 = 100.
variable labels total100 "Total".
value labels total100 100 "".

* ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = numChildren display = none
  /table   cage2 [c] 
   by 
           bf [c][rowpct.validn,'',f5.1] 
         + total100 [s][mean,'',f5.1] 
         + numChildren [c][count,'',f5.0] 
  /slabels position = column visable = no
  /categories var = all empty = exclude missing = exclude
  /titles title=
	"Working table for Figure NU.3: Infant feeding patterns by age" 
	"Percent distribution of children age 0-23 months by feeding pattern, " + surveyname.

weight off.

* ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = numChildren display = none
  /table   cage2 [c] 
   by      numChildren [c][count,'',f5.0] 
  /slabels position = column visable = no
  /categories var = all empty = exclude missing = exclude
  /titles title=
	"Working table for Figure NU.3: Unweighted denominators, " + surveyname.

new file.
